==> alfresco-repository-23.6.0.29-sources.jar: org/alfresco/email/server/handler/EmailMessageHandler.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.email.server.handler;

import org.alfresco.service.cmr.email.EmailMessage;
import org.alfresco.service.cmr.email.EmailMessageException;
import org.alfresco.service.cmr.repository.DuplicateChildNodeNameException;
import org.alfresco.service.cmr.repository.NodeRef;

/**
 * Interface for email handler for processing email message.
 * 
 * @author maxim
 * @since 2.2
 */
public interface EmailMessageHandler
{
    /**
     * Method invokes for processing email message.
     * 
     * @param nodeRef Target node
     * @param message Email message
     * @exception EmailMessageException Exception is thrown if processing was failed
     * @exception DuplicateChildNodeNameException Exception is thrown if node name is duplicate.
     */
    void processMessage(NodeRef nodeRef, EmailMessage message);

}

==> alfresco-repository-26.1.0.41-sources.jar: org/alfresco/email/server/handler/EmailMessageHandler.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.email.server.handler;

import org.alfresco.service.cmr.email.EmailMessage;
import org.alfresco.service.cmr.email.EmailMessageException;
import org.alfresco.service.cmr.repository.DuplicateChildNodeNameException;
import org.alfresco.service.cmr.repository.NodeRef;

/**
 * Interface for email handler for processing email message.
 * 
 * @author maxim
 * @since 2.2
 */
public interface EmailMessageHandler
{
    /**
     * Method invokes for processing email message.
     * 
     * @param nodeRef
     *            Target node
     * @param message
     *            Email message
     * @exception EmailMessageException
     *                Exception is thrown if processing was failed
     * @exception DuplicateChildNodeNameException
     *                Exception is thrown if node name is duplicate.
     */
    void processMessage(NodeRef nodeRef, EmailMessage message);

}
